@@ -1,6 +1,6 @@
 ;;; compat-27.el --- Functionality added in Emacs 27.1 -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
 ;;; Code:
 
 (eval-when-compile (load "compat-macs.el" nil t t))
-(compat-declare-version "27.1")
+(compat-require compat-26 "26.1")
+
+(compat-version "27.1")
 
 ;;;; Defined in fns.c
 
@@ -572,19 +574,6 @@ The return value is a string (or nil in case we can’t find it)."
             (or (lm-header "package-version")
                 (lm-header "version")))))))))
 
-;;;; Defined in dired.el
-
-(compat-defun dired-get-marked-files
-    (&optional localp arg filter distinguish-one-marked error)
-  "Obsolete function."
-  :obsolete "The compatibility function has been made obsolete."
-  :feature dired
-  :extended t
-  (let ((result (dired-get-marked-files localp arg filter distinguish-one-marked)))
-    (if (and (null result) error)
-        (user-error (if (stringp error) error "No files specified"))
-      result)))
-
 ;;;; Defined in time-date.el
 
 (compat-defun make-decoded-time ;; <compat-tests:make-decoded-time>
@@ -838,7 +827,7 @@ discarded."
 
 ;;;; Defined in map-ynp.el
 
-(compat-declare-version "26.2")
+(compat-version "26.2")
 
 (compat-defvar read-answer-short 'auto ;; <compat-tests:read-answer>
   "If non-nil, the `read-answer' function accepts single-character answers.
